# Last edited on 2007-04-19 02:29:01 by stolfi

JOBNAME := slides

EXPDIR := $${HOME}/public_html/slides-puc-rio-2007-04

NPAGES := 23
  
PARTS := \
  slide-dimensions.tex \
  \
  slides-020-cover.tex \
  slides-120-intro.tex \
  slides-220-digit.tex \
  slides-320-recon.tex \
  slides-420-imapp.tex \
  slides-520-apbas.tex \

NONPARTS := \
  slides-0.tex \
  slides-1.tex \
  slides-2.tex

MACROS := \
  macros-unframed-slides.tex \
  macros-epsbox.tex \
  macros-labelbox.tex \
  macros-captionbox.tex \
  macros-stolfi.tex \
  macros-approx-cg.tex
  
NONMACROS :=

BIBS := \
  stolfi.bib \
  students.bib \
  others.bib

SUBDIRS := \
  figures

NEWTEX := export TEXINPUTS=".::$${HOME}/tex/inputs/"

RUN_LATEX := run-latex
PSVIEW    := ghostview
PDFVIEW   := acroread
# PDFVIEW   := xpdf -t1lib high
  
OUTPSFILES := \
  ${JOBNAME}-v.ps \
  ${JOBNAME}-v.pdf
  
OUTZIPS := ${addsuffix .gz,${OUTFILES}}
  
NONOUTFILES := \
  ${JOBNAME}-h.ps \
  ${JOBNAME}-h.pdf

.SUFFIXES:

.PHONY: \
  all clean subdirs \
  show-v-ps show-v-pdf \
  show-h-ps show-h-pdf \
  install split-dvi

# all: subdirs ${OUTFILES} show-v-pdf install
all: subdirs ${OUTFILES} show-v-pdf

subdirs:
	@for dir in ${SUBDIRS} ; do \
	  ${MAKE} -f ${JOBNAME}.make SUBDIR=$$dir $$dir.done ; \
	done

######################################################################
# For recursive make - caller must define SUBDIR

SUBDIR := SUBDIR.IS.UNDEFINED
ifneq "${SUBDIR}/" "SUBDIR.IS.UNDEFINED/"

${SUBDIR}.done: ${SUBDIR}
	( cd ${SUBDIR} && ${MAKE} all ) ; /bin/touch ${SUBDIR}.done

endif
# End SUBDIR make
######################################################################

${JOBNAME}.dvi: ${JOBNAME}.tex ${PARTS} ${BIBS} ${MACROS} ${SUBDIRS}
	${NEWTEX}; ${RUN_LATEX} ${JOBNAME}

install: ${JOBNAME}-h.ps.gz ${JOBNAME}-v.ps.gz ${JOBNAME}-h.pdf ${JOBNAME}-v.pdf
	cp -av \
          ${JOBNAME}-h.ps.gz ${JOBNAME}-v.ps.gz \
          ${JOBNAME}-h.pdf ${JOBNAME}-v.pdf \
          ${EXPDIR}/

split-dvi: ${JOBNAME}.dvi 
	for p in `count 01 ${NPAGES}`; do \
          ${NEWTEX}; \
          dvips -D600 -p =$$p -n 1 \
            -t letter -t landscape -O 0mm,0mm \
            -o split-ps/${JOBNAME}-$$p.ps ${JOBNAME}; \
        done

######################################################################
# This seems to work:

${JOBNAME}-v.ps: ${JOBNAME}.dvi ${SUBDIRS}
	${NEWTEX}; dvips -D600 -t letter -t landscape -o ${JOBNAME}-v.ps ${JOBNAME}

show-v-ps: ${JOBNAME}-v.ps
	${PSVIEW} ${JOBNAME}-v.ps

${JOBNAME}-v.pdf: ${JOBNAME}-v.ps
	ps2pdf ${JOBNAME}-v.ps ${JOBNAME}-v.pdf

show-v-pdf: ${JOBNAME}-v.pdf
	${PDFVIEW} ${JOBNAME}-v.pdf

${JOBNAME}-v.ps.gz: ${JOBNAME}-v.ps
	cat ${JOBNAME}-v.ps | gzip > ${JOBNAME}-v.ps.gz

#
######################################################################

######################################################################
# Alternative (does not seem to work):

${JOBNAME}-h.ps: ${JOBNAME}.dvi ${SUBDIRS}
	${NEWTEX}; dvips -t letter -T 11in,8.5in -o ${JOBNAME}-h.ps -D600 ${JOBNAME}

${JOBNAME}-h.pdf: ${JOBNAME}-h.ps
	ps-to-pdf < ${JOBNAME}-h.ps > ${JOBNAME}-h.pdf

show-h-ps: ${JOBNAME}-h.ps
	${PSVIEW} ${JOBNAME}-h.ps

show-h-pdf: ${JOBNAME}-h.pdf
	${PDFVIEW} - ${JOBNAME}-h.pdf
  
${JOBNAME}-h.ps.gz: ${JOBNAME}-h.ps
	cat ${JOBNAME}-h.ps | gzip > ${JOBNAME}-h.ps.gz
#
######################################################################
